%define build_external_fuse 0
%define build_external_fuse 1

# flag to allow local users to mount partitions. This is *really* not a good
# idea, because all users who have access to the device can do whatever they
# want with the data, and it also adds a root setuid binary to your system, so
# use it on your own risk. Refer to
# http://www.tuxera.com/community/ntfs-3g-faq/#useroption for details.
%define allow_unsafe_mount 0
%if %allow_unsafe_mount
# user mount only works if ntfs-3g is using internal fuse library
%define build_external_fuse 0
%endif

%define major	89
%define libname %mklibname %{name} %{major}
%define develname %mklibname %{name} -d

Name:		ntfs-3g
Version:	2021.8.22
%define subrel 2
Release:	%mkrel 1
Summary:	Read-write ntfs driver
License:	GPLv2+
Group:		System/Base
URL:		https://www.tuxera.com/company/open-source/
Source0:	http://tuxera.com/opensource/%{name}_ntfsprogs-%{version}.tgz

BuildRequires:	pkgconfig(libattr)
BuildRequires:	libgcrypt-devel
BuildRequires:	pkgconfig(gnutls)
BuildRequires:  libuuid-devel
%if %build_external_fuse
BuildRequires:	pkgconfig(fuse) >= 2.8
Requires:	fuse >= 2.8
Requires(pre):	fuse >= 2.8
%else
Requires:	kmod(fuse)
%endif
Obsoletes:	ntfsprogs < 2.0.0-11
Provides:	ntfsprogs = %{version}-%{release}
Recommends:	ntfs-3g-system-compression

Patch0:		ntfs-3g_ntfsprogs-2011.10.9-RC-ntfsck-unsupported-return-0.patch
Patch1:		CVE-2021-46790.patch
Patch2:		CVE-2022-30783.patch
Patch3:		CVE-2022-30784.patch
Patch4:		CVE-2022-30785_30787.patch
Patch5:		CVE-2022-30786-1.patch
Patch6:		CVE-2022-30786-2.patch
Patch7:		CVE-2022-30788-1.patch
Patch8:		CVE-2022-30788-2.patch
Patch9:		CVE-2022-30789.patch
Patch10:	CVE-2022-40284-1.patch
Patch11:	CVE-2022-40284-2.patch

%description
NTFS-3G is a stable, open source, GPL licensed, POSIX, read/write NTFS 
driver for Linux and many other operating systems. It provides safe 
handling of the Windows XP, Windows Server 2003, Windows 2000, Windows 
Vista, Windows Server 2008 and Windows 7 NTFS file systems. NTFS-3G can 
create, remove, rename, move files, directories, hard links, and streams; 
it can read and write normal and transparently compressed files, including 
streams and sparse files; it can handle special files like symbolic links, 
devices, and FIFOs, ACL, extended attributes; moreover it provides full 
file access right and ownership support.

%package	-n %{libname}
Summary:	Library for ntfs-3g
Group:		System/Libraries
Conflicts:	%{name} < 2017.3.23-2

%description	-n %{libname}
This package contains the library needed to run programs dynamically
linked with libntfs-3g.

%package	-n %{develname}
Summary:	Development files and libraries for ntfs-3g
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Obsoletes:	%{_lib}ntfs-devel < 2.0.0-11
Obsoletes:	ntfs-3g-devel < 2017.3.23-2

%description	-n %{develname}
Headers and libraries for developing applications that use ntfs-3g
functionality.

%prep
%autosetup -n %{name}_ntfsprogs-%{version} -p1

%build
export CFLAGS="%{optflags} -fPIC"
%configure \
	--disable-static \
	--disable-ldconfig \
%if %build_external_fuse
	--with-fuse=external \
%else
	--with-fuse=internal \
%endif
	--exec-prefix=/ \
	--enable-posix-acls \
	--enable-xattr-mappings \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined

%make_build

%install
sed -i -e 's|/sbin/ldconfig|true|' src/Makefile
%make_install

rm -rf %{buildroot}%{_libdir}/*.la
rm -rf %{buildroot}%{_libdir}/*.a

# make the symlink an actual copy to avoid confusion
rm -rf %{buildroot}/%{_sbindir}/mount.ntfs-3g
cp -a %{buildroot}/%{_bindir}/ntfs-3g %{buildroot}/%{_sbindir}/mount.ntfs-3g

# Actually make some symlinks for simplicity...
# ... since we're obsoleting ntfsprogs-fuse
pushd %{buildroot}/%{_bindir}
ln -s ntfs-3g ntfsmount
popd
pushd %{buildroot}/%{_sbindir}
ln -s mount.ntfs-3g mount.ntfs-fuse
# And since there is no other package in Fedora that provides an ntfs 
# mount...
ln -s mount.ntfs-3g mount.ntfs
# Need this for fsck to find it
ln -s ../bin/ntfsck fsck.ntfs
popd

mv %{buildroot}/sbin/* %{buildroot}/%{_sbindir}
rmdir %{buildroot}/sbin

# We get this on our own, thanks.
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/README


%files
%doc README AUTHORS CREDITS NEWS
%{_bindir}/lowntfs-3g
%{_bindir}/ntfsmount
%{_bindir}/ntfs-3g
%{_bindir}/ntfs-3g.probe
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_bindir}/ntfssecaudit
%{_bindir}/ntfsusermap
# Extras
%{_bindir}/ntfsck
%{_bindir}/ntfsdecrypt
%{_bindir}/ntfsdump_logfile
%{_bindir}/ntfsfallocate
%{_bindir}/ntfsmftalloc
%{_bindir}/ntfsmove
%{_bindir}/ntfsrecover
%{_bindir}/ntfstruncate
%{_bindir}/ntfswipe
%{_sbindir}/fsck.ntfs
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{_mandir}/man8/*
%{_sbindir}/mount.ntfs
%if %allow_unsafe_mount
%attr(4755,root,root) %{_sbindir}/mount.ntfs-3g
%else
%attr(754,root,root) %{_sbindir}/mount.ntfs-3g
%endif
%{_sbindir}/mount.lowntfs-3g
%{_sbindir}/mount.ntfs-fuse

%files -n %{libname}
/%{_libdir}/libntfs-3g.so.%{major}{,.*}

%files -n %{develname}
%doc ChangeLog
/%{_libdir}/libntfs-3g.so
%{_includedir}/ntfs-3g
%{_libdir}/pkgconfig/libntfs-3g.pc


%changelog
* Thu Nov 03 2022 ns80 <ns80> 2021.8.22-1.2.mga8
+ Revision: 1901940
- add paches from Ubuntu for CVE-2022-40284 (mga#31056)
- add patches from Ubuntu for CVE-2021-46790, CVE-2022-3078[3-9] (mga#30479)
+ neoclust <neoclust>
- New version 2021.8.22 (mga#29428)
  Fixes CVE-2021-3328[5679]
      CVE-2021-3526[6-9]
      CVE-2021-3925[1-9]
      CVE-2021-3926[0-3]

* Thu Mar 12 2020 tv <tv> 2017.3.23-10.mga8
+ Revision: 1555870
- enable quarantined ntfsprogs utilities
- BR uuid b/c ntfsprogs DCE compliant UUID generation code requires the uuid library
- enable posix ACLS, enable xattr mappings
- provide a fsck.ntfs symlink
- simplify in a /usrMove world
- update description (also we don't have static libs)

* Thu Mar 12 2020 tv <tv> 2017.3.23-9.mga8
+ Revision: 1555844
- make clear patch 4 is about a CVE
- fix ntfsclone crash (rhbz#1601146)
- support bigger sector sizes on Windows 10
- add Recommends: ntfs-3g-system-compression. That allows people with
  Windows 10 to read system files.

* Sat Feb 15 2020 umeabot <umeabot> 2017.3.23-8.mga8
+ Revision: 1524101
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Tue Mar 26 2019 daviddavid <daviddavid> 2017.3.23-7.mga7
+ Revision: 1380292
- aad debian patch to fix CVE-2019-9755 (mga#24562)

* Sun Sep 23 2018 umeabot <umeabot> 2017.3.23-6.mga7
+ Revision: 1299807
- Mageia 7 Mass Rebuild

* Mon May 21 2018 zezinho <zezinho> 2017.3.23-5.mga7
+ Revision: 1231028
- added patch to read Win10cu written partitons

* Fri Apr 27 2018 wally <wally> 2017.3.23-4.mga7
+ Revision: 1222930
- fix devel pkg requires

* Fri Apr 27 2018 wally <wally> 2017.3.23-3.mga7
+ Revision: 1222929
- fix devel pkg obsoletes
- add conflicts for lib files splitted out from main pkg
- drop provides from lib pkg
- drop old obsoletes

* Fri Apr 27 2018 zezinho <zezinho> 2017.3.23-2.mga7
+ Revision: 1222903
- try to libify the package

* Sat Jul 22 2017 daviddavid <daviddavid> 2017.3.23-1.mga7
+ Revision: 1127812
- new version: 2017.3.23
- remove merged upstream patch

* Fri Feb 03 2017 luigiwalser <luigiwalser> 2016.2.22-4.mga6
+ Revision: 1084635
- add patch to fix CVE-2017-0358

* Mon Mar 21 2016 tv <tv> 2016.2.22-3.mga6
+ Revision: 993635
- adjust file list
- new release

* Tue Jan 12 2016 tv <tv> 2015.3.14-3.mga6
+ Revision: 922266
- rebuild for new gnutls

* Thu Sep 10 2015 fwang <fwang> 2015.3.14-2.mga6
+ Revision: 875429
- rebuild for new libgcrypt

* Sat Aug 15 2015 daviddavid <daviddavid> 2015.3.14-1.mga6
+ Revision: 864887
- new version: 2015.3.14
- add patch from Fedora to fix CVE-2015-3202
- update URL
- enable crypto and extras supports

* Wed Oct 15 2014 umeabot <umeabot> 2014.2.15-4.mga5
+ Revision: 747395
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 2014.2.15-3.mga5
+ Revision: 682946
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 wally <wally> 2014.2.15-2.mga5
+ Revision: 636622
- obsolete also lib and devel pkg from ntfsprogs

* Sat Mar 08 2014 tv <tv> 2014.2.15-1.mga5
+ Revision: 601224
- new release

* Sat Oct 19 2013 umeabot <umeabot> 2013.1.13-3.mga4
+ Revision: 529071
- Mageia 4 Mass Rebuild

* Wed Jul 03 2013 neoclust <neoclust> 2013.1.13-2.mga4
+ Revision: 449888
- apply fixes from upstream for issue with 4K sector drives (bz951603)
  and truncated check for Interix types on a 32-bit CPU (bz958681)
- fix bug preventing reads on compressed files on windows 8 partitions (bz967301)

* Sun May 26 2013 blino <blino> 2013.1.13-1.mga4
+ Revision: 428262
- 2013.1.13

* Sun Feb 24 2013 neoclust <neoclust> 2012.1.15-3.mga3
+ Revision: 400267
- Fix obsoleting as here %%rename does not work ( reported on irc )
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Jan 23 2012 fwang <fwang> 2012.1.15-1.mga2
+ Revision: 200184
- new vesion 2012.1.15

* Mon Dec 05 2011 fwang <fwang> 2011.4.12-3.mga2
+ Revision: 176807
- drop .la file

* Thu Jun 16 2011 tv <tv> 2011.4.12-2.mga2
+ Revision: 108396
- fix file list
- new release (merged with ntfsprogs)

* Thu Mar 03 2011 eandry <eandry> 2011.1.15-1.mga1
+ Revision: 63460
- New version 2011.1.15
- clean spec
- drop hal stuff

* Sat Jan 15 2011 blino <blino> 2010.10.2-2.mga1
+ Revision: 18785
- remove old ldconfig scriptlets and build conditionals
- imported package ntfs-3g


* Fri Dec 03 2010 Oden Eriksson <oeriksson@mandriva.com> 2010.10.2-2mdv2011.0
+ Revision: 606830
- rebuild

* Mon Oct 04 2010 Funda Wang <fwang@mandriva.org> 2010.10.2-1mdv2011.0
+ Revision: 582800
- New version 2010.10.2

* Mon Aug 09 2010 Funda Wang <fwang@mandriva.org> 2010.8.8-1mdv2011.0
+ Revision: 567843
- update to new version 2010.8.8
- add conflicts on older ntfsprogs

* Sun Jul 11 2010 Funda Wang <fwang@mandriva.org> 2010.5.22-1mdv2011.0
+ Revision: 550636
- New version 2010.5.22

* Mon May 17 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.5.16-1mdv2011.0
+ Revision: 544955
- Updated to 2010.5.16.

* Tue Mar 30 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-3mdv2010.1
+ Revision: 529725
- Add a flag to allow enabling user mounts (#45476).

* Mon Mar 15 2010 Eugeni Dodonov <eugeni@mandriva.com> 2010.3.6-2mdv2010.1
+ Revision: 519941
- Provide mount.ntfs, mount.ntfs-fuse and ntfsmount.

* Tue Mar 09 2010 Funda Wang <fwang@mandriva.org> 2010.3.6-1mdv2010.1
+ Revision: 516823
- New version 2010.3.6
- update desc

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-2mdv2010.1
+ Revision: 493078
- use root group rather than fuse (bug#57113)

* Mon Jan 18 2010 Funda Wang <fwang@mandriva.org> 2010.1.16-1mdv2010.1
+ Revision: 492931
- New version 2010.1.16
- update url

* Mon Nov 16 2009 Funda Wang <fwang@mandriva.org> 2009.11.14-1mdv2010.1
+ Revision: 466631
- fix build
- new version 2009.11.14

* Mon Sep 21 2009 Eugeni Dodonov <eugeni@mandriva.com> 2009.4.4-2mdv2010.0
+ Revision: 446533
- Installing ntfs-3g as default driver for ntfs partitions (#53795).

* Fri Apr 03 2009 Frederic Crozat <fcrozat@mandriva.com> 2009.4.4-1mdv2009.1
+ Revision: 363764
- Release 2009.4.4
- Remove patch1 (fixed upstream)

* Tue Mar 31 2009 Funda Wang <fwang@mandriva.org> 2009.3.8-1mdv2009.1
+ Revision: 362967
- New version 2009.3.8

* Mon Mar 30 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-3mdv2009.1
+ Revision: 362378
- Update /etc/mtab but do not wait for the process

* Fri Mar 27 2009 Pascal Terjan <pterjan@mandriva.org> 2009.2.1-2mdv2009.1
+ Revision: 361736
- Disable mtab updating until a solution for deadlock is found

* Thu Feb 12 2009 Frederik Himpe <fhimpe@mandriva.org> 2009.2.1-1mdv2009.1
+ Revision: 339900
- update to new version 2009.2.1

* Fri Jan 23 2009 Funda Wang <fwang@mandriva.org> 2009.1.1-1mdv2009.1
+ Revision: 332743
- new version 2009.1.1

* Tue Dec 02 2008 Funda Wang <fwang@mandriva.org> 1.5130-1mdv2009.1
+ Revision: 309199
- update to new version 1.5130

* Sun Oct 12 2008 Funda Wang <fwang@mandriva.org> 1.5012-1mdv2009.1
+ Revision: 292619
- New version 1.5012

* Fri Sep 19 2008 Funda Wang <fwang@mandriva.org> 1.2918-1mdv2009.0
+ Revision: 285808
- New version 1.2918

* Sat Aug 16 2008 Funda Wang <fwang@mandriva.org> 1.2812-2mdv2009.0
+ Revision: 272609
- New version 1.2812

* Tue Jul 29 2008 Funda Wang <fwang@mandriva.org> 1.2712-2mdv2009.0
+ Revision: 252183
- fix perms (bug#42306)
- remove incorrect doc dir

* Tue Jul 15 2008 Funda Wang <fwang@mandriva.org> 1.2712-1mdv2009.0
+ Revision: 235723
- New version 1.2712
- use internal fuse even in cooker, as external dependency requires fuse 2.8

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Thu May 29 2008 Funda Wang <fwang@mandriva.org> 1.2531-1mdv2009.0
+ Revision: 213061
- New version 1.2531

* Wed May 07 2008 Funda Wang <fwang@mandriva.org> 1.2506-1mdv2009.0
+ Revision: 202735
- New version 1.2506

* Tue Apr 15 2008 Funda Wang <fwang@mandriva.org> 1.2412-1mdv2009.0
+ Revision: 193607
- New version 1.2412
- obsoletes libntfs-3g, as it produces too many libmajor, and it is not used by other packages
- New version 1.2310
- add fedora patch to fix rhbug#403291 (ignore -n option)

* Mon Feb 18 2008 Funda Wang <fwang@mandriva.org> 1.2216-1mdv2008.1
+ Revision: 171456
- New version 1.2216

* Fri Feb 08 2008 Funda Wang <fwang@mandriva.org> 1.2129-4mdv2008.1
+ Revision: 164013
- move prefix from /usr to /, which solve the problems if
  /usr is not mounted at boot time.

* Fri Feb 01 2008 Funda Wang <fwang@mandriva.org> 1.2129-3mdv2008.1
+ Revision: 161148
- mount.ntfs-3g should be in /sbin rather thatn /usr/sbin (bug#37352)

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-2mdv2008.1
+ Revision: 159884
- fuse is not required for old distro
- add conditional building for fuse

* Tue Jan 29 2008 Funda Wang <fwang@mandriva.org> 1.2129-1mdv2008.1
+ Revision: 159810
- New version 1.2129

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Tue Nov 20 2007 Funda Wang <fwang@mandriva.org> 1.1120-1mdv2008.1
+ Revision: 110711
- New version 1.1104
- New major ( 14-> 16 )

* Tue Nov 06 2007 Funda Wang <fwang@mandriva.org> 1.1104-2mdv2008.1
+ Revision: 106394
- rebuild for new lzma

* Mon Nov 05 2007 Funda Wang <fwang@mandriva.org> 1.1104-1mdv2008.1
+ Revision: 106003
- New version 1.1104

* Thu Nov 01 2007 Funda Wang <fwang@mandriva.org> 1.1030-1mdv2008.1
+ Revision: 104318
- New version 1.1030
- New major ( 13 -> 14 )

* Sun Oct 14 2007 Funda Wang <fwang@mandriva.org> 1.1004-2mdv2008.1
+ Revision: 98262
- drop README.install.urpmi, as our kernel is new enough

* Tue Oct 09 2007 Funda Wang <fwang@mandriva.org> 1.1004-1mdv2008.1
+ Revision: 96173
- New major
- New version 1.1004

* Thu Aug 30 2007 Funda Wang <fwang@mandriva.org> 1.826-1mdv2008.0
+ Revision: 75140
- New major
- New version 1.826

* Sun Aug 12 2007 Funda Wang <fwang@mandriva.org> 1.810-1mdv2008.0
+ Revision: 62256
- new major
- New version 1.810

* Thu Jul 26 2007 Helio Chissini de Castro <helio@mandriva.com> 1.710-2mdv2008.0
+ Revision: 56065
- Elegant solution from ArchLinux to enable hal backends to use ntfs-3g instead of standard ntfs
  driver. KDE now mount external and local ntfs storage devices rw by default as long ntfs-3f is
  installed. gnome-mount is not affected, as use different strategy.

  + Götz Waschk <waschk@mandriva.org>
    - fix doc file listing

* Mon Jul 16 2007 Götz Waschk <waschk@mandriva.org> 1.710-1mdv2008.0
+ Revision: 52424
- new version
- rename devel package

* Sun Jun 24 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.616-1mdv2008.0
+ Revision: 43669
- new version: 1.616
- new major

* Fri May 25 2007 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.516-1mdv2008.0
+ Revision: 31052
- build on all architectures (worked just fine on my sparc :)
- new release: 1.516
  new major
  add url to source


* Thu Feb 22 2007 Götz Waschk <waschk@mandriva.org> 1.0-2mdv2007.0
+ Revision: 124370
- fix description
- fix group
- add warning about FUSE version

  + Frederic Crozat <fcrozat@mandriva.com>
    - Fix description

* Wed Feb 21 2007 Götz Waschk <waschk@mandriva.org> 1.0-1mdv2007.1
+ Revision: 123213
- new version
- fix build
- remove warning at installation, this isn't considered beta anymore

  + Thierry Vignaud <tvignaud@mandriva.com>
    - new URL

  + Jérôme Soyer <saispo@mandriva.org>
    - Import ntfs-3g

* Tue Sep 26 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070920.1mdv2007.0
- 20070920-BETA

* Fri Jul 21 2006 Couriousous <couriousous@mandriva.org> 0.1-0.20070714.2mdv2007.0
- Some spec cleanup
- Build only on ix86
- Upload to contrib

* Thu Jul 20 2006 Davide Duina <davide.duina_AT_gmail_DOT_com> 0.1-0.20070714.1mdv2007.0
- First version, based on Beta 20070714

